@@ -59,7 +59,7 @@ class quantum_lab():
                 filePath = f"{self.volumePath}/{fileName}"
 
         if filePath == "":
-            raise ValueError(f"File {fileName} not found.")
+            raise ValueError(f"[ERROR]File {fileName} not found.")
 
         url_path = f"{self.url}/qcc/notebook/job"
 
@@ -119,7 +119,7 @@ class quantum_lab():
                 filePath = f"{self.volumePath}/{fileName}"
 
         if filePath == "":
-            raise ValueError(f"File {fileName} not found.")
+            raise ValueError(f"[ERROR]File {fileName} not found.")
 
         url_path = f"{self.url}/qcc/notebook/job"
 
